@@ -218,6 +218,8 @@ gtk_gs_init (GtkGS *gs)
         gs->reading_from_pipe = FALSE;
         gs->send_filename_to_gs = FALSE;
 
+        gs->doc = NULL;
+
 	gs->interpreter_input = -1;
 	gs->interpreter_output = -1;
 	gs->interpreter_err = -1;
@@ -275,6 +277,40 @@ gtk_gs_class_init (GtkGSClass *klass)
         klass->string_atom    = gdk_atom_intern ("STRING", FALSE);
 }
 
+/* Clean all memory and temporal files */
+static void 
+gtk_gs_cleanup (GtkGS *gs)
+{
+        g_return_if_fail (gs != NULL);
+        g_return_if_fail (GTK_IS_GS (gs));
+
+        stop_interpreter(gs);
+
+        if (gs->gs_filename)
+                g_free(gs->gs_filename);
+        if (gs->gs_filename_raw)
+                g_free(gs->gs_filename_raw);
+        if (gs->doc)
+                psfree(gs->doc);
+        
+        if (gs->gs_filename_dsc){
+                /*
+                g_print("Removing dsc temp file: %s\n", gs->gs_filename_dsc);
+                */
+                unlink(gs->gs_filename_dsc);
+                gs->gs_filename_dsc = NULL;
+        }
+        
+        if (gs->gs_filename_unc){
+                /*
+                g_print("Removing unc temp file: %s\n", gs->gs_filename_unc);
+                */
+                unlink(gs->gs_filename_unc);
+                gs->gs_filename_unc = NULL;
+        }
+        gs->doc = NULL;
+  
+}
 
 static void
 gtk_gs_destroy (GtkObject *object)
@@ -286,8 +322,8 @@ gtk_gs_destroy (GtkObject *object)
         
         gs = GTK_GS (object);
 
-        stop_interpreter(gs);
-  
+        gtk_gs_cleanup(gs);
+
         if (GTK_OBJECT_CLASS (parent_class)->destroy)
                 (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
@@ -1129,16 +1165,8 @@ gtk_gs_load (GtkGS *gs, char *fname)
                  */
 
 		/* clean up previous document */
-                gtk_gs_disable_interpreter(gs);
-		if (gs->gs_filename)
-                        g_free(gs->gs_filename);
-		if (gs->gs_filename_raw)
-                        g_free(gs->gs_filename_raw);
-                if (gs->doc)
-                        psfree(gs->doc);
-                gs->gs_filename_dsc = NULL;
-                gs->gs_filename_unc = NULL;
-		gs->doc = NULL;
+
+                gtk_gs_cleanup(gs);
 
 		/* prepare this document */
 		if ((gs->gs_psfile = fopen(fname, "r")) == NULL)
@@ -1176,7 +1204,10 @@ gtk_gs_load (GtkGS *gs, char *fname)
                                 psfree(gs->doc);
                         gs->gs_filename = NULL;
                         gs->gs_filename_raw = NULL;
+                        if (gs->gs_filename_dsc) {
                         gs->gs_filename_dsc = NULL;
+                        }
+                        
                         gs->gs_filename_unc = NULL;
                         gs->doc = NULL;
                         gs->llx = 0;
