@@ -17,6 +17,19 @@
 #include "crop.h"
 #include "prefs.h"
 
+/* This sizes are good for the worst case: laptops :) */
+
+#define DEFAULT_WINDOW_WIDTH  640
+#define DEFAULT_WINDOW_HEIGHT 480
+
+enum {
+        GEOMETRY_KEY = -1,
+        SPARTAN_KEY = -2,
+        NO_MENU_BAR_KEY = -3,
+};
+
+static gint width = DEFAULT_WINDOW_WIDTH, height = DEFAULT_WINDOW_HEIGHT;
+
 enum {
 		TARGET_URI_LIST,
 };
@@ -29,7 +42,7 @@ static GdkCursor *pan_cursor = NULL;
 
 struct _window_with_data {
         ggv_window *ggv;
-        gint data;
+        gpointer data;
 };
 
 struct _ggv_window {
@@ -135,6 +148,98 @@ static void zoomout_callback(GtkWidget *widget, gpointer *data);
 static void recent_add(char *filename);
 static void recent_update_menus (ggv_window *ggv, GList *recent_files);
 static void recent_cb(GtkWidget *w, gpointer *data);
+static char *geometry = 0;
+static gboolean spartan = FALSE;
+static gint     nomenubar = FALSE;
+
+static int
+get_number (const char **geometry)
+{
+	int value = 0;
+	int mult  = 1;
+	
+	if (**geometry == '-'){
+		mult = -1;
+		(*geometry)++;
+	}
+	while (**geometry && isdigit (**geometry)){
+		value = value * 10 + (**geometry - '0');
+		(*geometry)++;
+	}
+	return value * mult;
+}
+
+
+
+static gboolean
+ggv_parse_geometry (const gchar *geometry, 
+                    gint *xpos, gint *ypos, 
+                    gboolean *xneg, gboolean *yneg,
+                    gint *width, 
+                    gint *height)
+{
+	int subtract;
+
+	g_return_val_if_fail (xpos != NULL, FALSE);
+	g_return_val_if_fail (ypos != NULL, FALSE);
+	g_return_val_if_fail (width != NULL, FALSE);
+	g_return_val_if_fail (height != NULL, FALSE);
+	g_return_val_if_fail (yneg != NULL, FALSE);
+	g_return_val_if_fail (xneg != NULL, FALSE);
+	
+	*xpos = *ypos = *width = *height = -1;
+        *xneg = FALSE; *yneg = FALSE;
+
+	if (!geometry)
+		return FALSE;
+
+	if (*geometry == '=')
+		geometry++;
+	if (!*geometry)
+		return FALSE;
+	if (isdigit (*geometry))
+		*width = get_number (&geometry);
+	if (!*geometry)
+		return TRUE;
+	if (*geometry == 'x' || *geometry == 'X'){
+		geometry++;
+		*height = get_number (&geometry);
+	}
+	if (!*geometry)
+		return 1;
+	if (*geometry == '+'){
+		subtract = 0;
+		geometry++;
+	} else if (*geometry == '-'){
+		subtract = gdk_screen_width ();
+		geometry++;
+	} else
+		return FALSE;
+	*xpos = get_number (&geometry);
+	if (subtract) {
+		*xpos = subtract - *xpos;
+                *xneg = TRUE;
+        }
+	if (!*geometry)
+		return TRUE;
+	if (*geometry == '+'){
+		subtract = 0;
+		geometry++;
+	} else if (*geometry == '-'){
+		subtract = gdk_screen_height ();
+		geometry++;
+	} else
+		return FALSE;
+	*ypos = get_number (&geometry);
+	if (subtract) {
+		*ypos = subtract - *ypos;
+                *yneg = TRUE;
+        }
+	return TRUE;
+}
+
+
+
 
 static void
 recent_cb(GtkWidget *w, gpointer *data)
@@ -173,6 +278,9 @@ recent_update_menus (ggv_window *ggv, GList *recent_files)
 	int i;
         window_with_data *wwd;
 
+
+        if (!ggv->show_menus)
+                return;
         /*
         g_print("Num recent %d\n", gs_num_recent);
         */
@@ -214,7 +322,7 @@ recent_update_menus (ggv_window *ggv, GList *recent_files)
                 
 		menu->moreinfo = (gpointer) recent_cb;
 
-                wwd->data = (int)g_strdup(g_list_nth_data (recent_files, i));
+                wwd->data = g_strdup(g_list_nth_data (recent_files, i));
                 wwd->ggv = ggv;
 
 		menu->user_data = wwd;
@@ -854,7 +962,9 @@ static void orientation_callback(GtkWidget *widget, gpointer data)
         window_with_data *wwd = (window_with_data *) data;
         ggv_window *ggv = wwd->ggv;
 
-        if (gtk_gs_set_orientation (GTK_GS(ggv->gs), wwd->data))
+        if (!ggv->loaded)
+                return;
+        if (gtk_gs_set_orientation (GTK_GS(ggv->gs), GPOINTER_TO_INT(wwd->data)))
                 gtk_gs_goto_page (GTK_GS(ggv->gs), GTK_GS(ggv->gs)->current_page);
 }
 
@@ -995,9 +1105,9 @@ static void zoom_callback(GtkWidget *widget, gpointer data)
         window_with_data *wwd = (window_with_data *) data;
         ggv_window *ggv = wwd->ggv;
 
-        if (ggv->zoom_magstep == wwd->data) 
+        if (ggv->zoom_magstep == GPOINTER_TO_INT(wwd->data)) 
                 return;
-	zoom_to(ggv, wwd->data);
+	zoom_to(ggv, GPOINTER_TO_INT(wwd->data));
 }
 
 static void zoomin_callback(GtkWidget *widget, gpointer *data)
@@ -1209,7 +1319,6 @@ create_menus(ggv_window *retval, window_with_data *temp)
 
         gtk_widget_set_sensitive (GTK_WIDGET(fileMenu[5].widget), FALSE);
         gtk_widget_set_sensitive (GTK_WIDGET(fileMenu[6].widget), FALSE);
-        gtk_widget_set_sensitive (GTK_WIDGET(fileMenu[8].widget), FALSE);
 }        
 
 static void
@@ -1309,6 +1418,7 @@ ggv_window *create_ggv_window()
 	};
 	static gint n_drop_types = sizeof (drop_types) / sizeof(drop_types[0]);
 
+        gboolean bxneg, byneg;
         gint i;
         GtkWidget *hbox;
         GtkWidget *vbox;
@@ -1316,14 +1426,46 @@ ggv_window *create_ggv_window()
 
         ggv_window *retval = g_new0 (ggv_window, 1);
 
-        retval->show_menus = gs_menubar;
-        retval->show_panel = gs_panel;
+        if (nomenubar)
+                retval->show_menus = FALSE;
+        else
+                retval->show_menus = gs_menubar;
+
+        if (spartan)
+                retval->show_panel = FALSE;
+        else
+                retval->show_panel = gs_panel;
+
         retval->loaded = FALSE;
         retval->pan = FALSE;
 
         /* create the main window. */
         retval->main_window = gnome_app_new("ggv", "ggv:");
-        gtk_window_set_default_size(GTK_WINDOW(retval->main_window), 640, 480);
+
+
+        if (geometry){
+                int xpos, ypos;
+         
+                ggv_parse_geometry (geometry, &xpos, &ypos, &bxneg, &byneg, &width, &height);
+                g_print("Geometry %u %u %u %u\n", xpos, ypos, width, height);
+                
+                if (xpos != -1 && ypos != -1) {
+                        if (bxneg) xpos -= width;
+                        /* FIXME we need to know the vertical size of
+                           the current window bar */
+                        if (byneg) ypos -= height + 18;
+                        gtk_widget_set_uposition (GTK_WIDGET (retval->main_window), xpos, ypos);
+                }
+                if (width == -1 || height == -1) {
+                        width = DEFAULT_WINDOW_WIDTH;
+                        height = DEFAULT_WINDOW_HEIGHT;
+                }
+         /* Only the first window gets --geometry treatment for now */
+                geometry = NULL;
+        }
+
+        gtk_window_set_default_size(GTK_WINDOW(retval->main_window), 
+                                    width, height);
         gtk_window_set_policy(GTK_WINDOW(retval->main_window), TRUE, TRUE, FALSE);
         retval->cd = NULL;
         /* make it a drop zone for files */
@@ -1343,27 +1485,27 @@ ggv_window *create_ggv_window()
         for (i = 0; i < 16; i++)
                 retval->menudata[i].ggv = retval;
 
-        retval->menudata[0].data = GTK_GS_ORIENTATION_DEFAULT;
-        retval->menudata[1].data = GTK_GS_ORIENTATION_PORTRAIT;
-        retval->menudata[2].data = GTK_GS_ORIENTATION_LANDSCAPE;
-        retval->menudata[3].data = GTK_GS_ORIENTATION_SEASCAPE;
-        retval->menudata[4].data = GTK_GS_ORIENTATION_UPSIDEDOWN;
+        retval->menudata[0].data = GINT_TO_POINTER(GTK_GS_ORIENTATION_DEFAULT);
+        retval->menudata[1].data = GINT_TO_POINTER(GTK_GS_ORIENTATION_PORTRAIT);
+        retval->menudata[2].data = GINT_TO_POINTER(GTK_GS_ORIENTATION_LANDSCAPE);
+        retval->menudata[3].data = GINT_TO_POINTER(GTK_GS_ORIENTATION_SEASCAPE);
+        retval->menudata[4].data = GINT_TO_POINTER(GTK_GS_ORIENTATION_UPSIDEDOWN);
 
 	/* We are lying a little here - the magstep does not give
 	 * these ratios exactly but who's going to know ;)
 	 */
 
-        retval->menudata[5].data = -13;
-        retval->menudata[6].data = -12;
-        retval->menudata[7].data = -8; 
-        retval->menudata[8].data = -4; 
-        retval->menudata[9].data = -2; 
-        retval->menudata[10].data = 0;
-        retval->menudata[11].data = 2;
-        retval->menudata[12].data = 4;
-        retval->menudata[13].data = 8;
-        retval->menudata[14].data = 12;
-        retval->menudata[15].data = 13;
+        retval->menudata[5].data = GINT_TO_POINTER(-13);
+        retval->menudata[6].data = GINT_TO_POINTER(-12);
+        retval->menudata[7].data = GINT_TO_POINTER(-8); 
+        retval->menudata[8].data = GINT_TO_POINTER(-4); 
+        retval->menudata[9].data = GINT_TO_POINTER(-2); 
+        retval->menudata[10].data = GINT_TO_POINTER(0);
+        retval->menudata[11].data = GINT_TO_POINTER(2);
+        retval->menudata[12].data = GINT_TO_POINTER(4);
+        retval->menudata[13].data = GINT_TO_POINTER(8);
+        retval->menudata[14].data = GINT_TO_POINTER(12);
+        retval->menudata[15].data = GINT_TO_POINTER(13);
 
         /* Statusbar */
         retval->appbar = gnome_appbar_new(FALSE, TRUE, GNOME_PREFERENCES_USER);
@@ -1371,7 +1513,7 @@ ggv_window *create_ggv_window()
         gnome_app_set_statusbar(GNOME_APP(retval->main_window), retval->appbar);
 
         /* Menus */
-        if(gs_menubar)
+        if (retval->show_menus)
                 create_menus (retval, retval->menudata);
         create_popup_menus(retval);
 
@@ -1401,7 +1543,8 @@ ggv_window *create_ggv_window()
         retval->zoom_magstep = 0; /* 1 : 1 */
 
         retval->sidebar = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
-        if(gs_panel)
+
+        if(retval->show_panel)
                 create_sidebar(retval);
 
         /* We layout the page */
@@ -1418,12 +1561,14 @@ ggv_window *create_ggv_window()
 
         retval->file_sel = NULL;
 
-        if(gs_menubar) {
+
+
+        if (retval->show_menus)
                 gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(retval->menus_vis),
-                                                retval->show_menus);
+                                        retval->show_menus);
+        if(retval->show_panel)
                 gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(retval->panel_vis),
                                                 retval->show_panel);
-        }
         retval->bRecentHasBeenInstantiated = FALSE;
         return retval;
 }
@@ -1710,6 +1855,59 @@ apply_gs_prefs(GList *windows)
         }
 }
 
+static void
+parse_an_arg (poptContext state,
+           enum poptCallbackReason reason,
+           const struct poptOption *opt,
+           const char *arg, void *data)
+ {
+     struct terminal_config *cfg = data;
+ 
+     int key = opt->val;
+ 
+     switch (key){
+     case GEOMETRY_KEY:
+             geometry = (char *)arg;
+             break;
+     case SPARTAN_KEY:
+             spartan = TRUE;
+             break;
+     case NO_MENU_BAR_KEY:
+             nomenubar = TRUE;
+             break;
+     }
+
+}
+
+static struct poptOption options_callback [] = {
+        { NULL, '\0', POPT_ARG_CALLBACK, parse_an_arg, 0},
+        
+        { "geometry", '\0', POPT_ARG_STRING, NULL, GEOMETRY_KEY,
+          N_("Specifies the geometry for the main window"), N_("GEOMETRY")},
+      
+	{ "spartan", '\0', POPT_ARG_NONE, NULL, SPARTAN_KEY,
+	  N_("Do not use sidebar"), N_("SPARTAN") },
+
+	{ "nomenubar", '\0', POPT_ARG_NONE, NULL, NO_MENU_BAR_KEY,
+	  N_("Do not use a menu bar"), N_("NOMENUBAR") },
+
+
+        
+        { NULL, '\0', 0, NULL, 0}
+};
+
+
+static gboolean
+ggv_file_readable(char *FileName)
+{
+        struct stat StatRecord;
+        if (stat(FileName,&StatRecord) == 0) 
+                return (stat(FileName,&StatRecord) == 0);
+        return FALSE;
+}
+
+
+
 /* and we finally start the main prog. */
 int
 main(int argc, char *argv[])
@@ -1718,13 +1916,18 @@ main(int argc, char *argv[])
 	poptContext ctx;
 	char **startups;
 	int i;
-        
+        char *FileName, *AlterFileName;
+        gboolean Done;
+
         active_ggv=0;
 
+
         bindtextdomain (PACKAGE, GNOMELOCALEDIR);
         textdomain (PACKAGE);
 
-	gnome_init_with_popt_table("gnome-ghostview", VERSION, argc, argv, NULL, 0, &ctx);
+	gnome_init_with_popt_table("gnome-ghostview", 
+                                   VERSION, argc, argv, options_callback, 
+                                   0, &ctx);
 
         window_list = NULL;
 
@@ -1732,9 +1935,36 @@ main(int argc, char *argv[])
 
         startups = poptGetArgs(ctx);
         if(startups) {
-                for(i = 0; startups[i]; i++)
-                        open_window(startups[i]);
+                for(i = 0; startups[i]; i++) {
+                        FileName = startups[i];
+                        AlterFileName = NULL;
+                        Done = FALSE;
+                        if (!ggv_file_readable(FileName)) {
+                                AlterFileName = g_malloc(strlen(startups[i])+8);
+                                sprintf(AlterFileName, "%s.ps", FileName);
+                        }
+                        else
+                                Done = TRUE;
+                        if (!Done && !ggv_file_readable(AlterFileName)) 
+                                sprintf(AlterFileName, "%s.ps.gz", FileName);
+                        else
+                                Done = TRUE;
+
+                        if (!Done && !ggv_file_readable(AlterFileName)) 
+                                sprintf(AlterFileName, "%s.pdf", FileName);
+                        else
+                                Done = TRUE;
+
+
+                        if (AlterFileName) FileName = AlterFileName;
+                        if (Done) { 
+                                open_window(FileName);
+                                g_print("opening %s [%s]\n", FileName,AlterFileName);
+                        }
+                        if (AlterFileName) g_free(AlterFileName);
+                }
         }
+
 	poptFreeContext(ctx);
 
         if (window_list == NULL)
