@@ -229,7 +229,7 @@ char *
 file_getTmpFilename(tmpprefix)
    const gchar *tmpprefix;
 {
-  char *buf = malloc(BUFSIZ);
+  char *buf = g_malloc(BUFSIZ);
   if (buf == NULL) {
 	fprintf(stderr, "Fatal Error: Dynamic memory exhausted.\n");
 	exit(-1);
@@ -300,7 +300,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		if (tmpfile) fclose(tmpfile);
 		unlink(filename_unc);
 		unc_ok:
-		free(filename_unc);
+		g_free(filename_unc);
 		return(retval);
 	}
 	tmpfile = fopen(filename_unc, "r");
@@ -325,7 +325,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
     /* Header comments */
 
     if (iscomment(line,"%!PS-Adobe-") || iscomment(line,"%!PS")) {
-	doc = (struct document *) malloc(sizeof(struct document));
+	doc = (struct document *) g_malloc(sizeof(struct document));
 	if (doc == NULL) {
 	    fprintf(stderr, "Fatal Error: Dynamic memory exhausted.\n");
 	    exit(-1);
@@ -357,7 +357,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		if (tmpfile) fclose(tmpfile);
 		unlink(filename_dsc);
 		scan_ok:
-		free(filename_dsc);
+		g_free(filename_dsc);
 		return(retval);
 	}
 	tmpfile = fopen(filename_dsc, "r");
@@ -389,7 +389,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 	 the !PS at the beginning.
 
       */
-	doc = (struct document *) malloc(sizeof(struct document));
+	doc = (struct document *) g_malloc(sizeof(struct document));
 	if (doc == NULL) {
 	    fprintf(stderr, "Fatal Error: Dynamic memory exhausted.\n");
 	    exit(-1);
@@ -506,7 +506,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		   iscomment(line+2, "DocumentMedia:")) {
 	    float w, h;
 	    doc->media = (struct documentmedia *)
-			 malloc(sizeof (struct documentmedia));
+			 g_malloc(sizeof (struct documentmedia));
 	    if (doc->media == NULL) {
 		fprintf(stderr, "Fatal Error: Dynamic memory exhausted.\n");
 		exit(-1);
@@ -521,7 +521,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		if (doc->media[0].width != 0 && doc->media[0].height != 0)
 		    doc->nummedia = 1;
 		else
-		    free(doc->media[0].name);
+		    g_free(doc->media[0].name);
 	    }
 	    preread=1;
 	    while (readline(line, sizeof line, file, &position, &line_len) &&
@@ -545,7 +545,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		    if (doc->media[doc->nummedia].width != 0 &&
 			doc->media[doc->nummedia].height != 0) doc->nummedia++;
 		    else
-			free(doc->media[doc->nummedia].name);
+			g_free(doc->media[doc->nummedia].name);
 		}
 	    }
 	    section_len += line_len;
@@ -554,7 +554,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		   iscomment(line+2, "DocumentPaperSizes:")) {
 
 	    doc->media = (struct documentmedia *)
-			 malloc(sizeof (struct documentmedia));
+			 g_malloc(sizeof (struct documentmedia));
 	    if (doc->media == NULL) {
 		fprintf(stderr, "Fatal Error: Dynamic memory exhausted.\n");
 		exit(-1);
@@ -570,9 +570,9 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		     * PaperSize comments.
 		     */
 		    if (strcasecmp(doc->media[0].name, dmp->name) == 0) {
-			free(doc->media[0].name);
+			g_free(doc->media[0].name);
 			doc->media[0].name =
-				(char *)malloc(strlen(dmp->name)+1);
+				(char *)g_malloc(strlen(dmp->name)+1);
 			if (doc->media[0].name == NULL) {
 			    fprintf(stderr,
 				    "Fatal Error: Dynamic memory exhausted.\n");
@@ -587,7 +587,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		if (doc->media[0].width != 0 && doc->media[0].height != 0)
 		    doc->nummedia = 1;
 		else
-		    free(doc->media[0].name);
+		    g_free(doc->media[0].name);
 	    }
 	    while ( (cp = get_next_text(next_char, &next_char)) ) {
 		doc->media = (struct documentmedia *)
@@ -608,9 +608,9 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		     */
 		    if (strcasecmp(doc->media[doc->nummedia].name,
 			       dmp->name) == 0) {
-			free(doc->media[doc->nummedia].name);
+			g_free(doc->media[doc->nummedia].name);
 			doc->media[doc->nummedia].name =
-				(char *)malloc(strlen(dmp->name)+1);
+				(char *)g_malloc(strlen(dmp->name)+1);
 			if (doc->media[doc->nummedia].name == NULL) {
 			    fprintf(stderr,
 				    "Fatal Error: Dynamic memory exhausted.\n");
@@ -626,7 +626,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		if (doc->media[doc->nummedia].width != 0 &&
 		    doc->media[doc->nummedia].height != 0) doc->nummedia++;
 		else
-		    free(doc->media[doc->nummedia].name);
+		    g_free(doc->media[doc->nummedia].name);
 	    }
 	    preread=1;
 	    while (readline(line, sizeof line, file, &position, &line_len) &&
@@ -661,7 +661,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 		    if (doc->media[doc->nummedia].width != 0 &&
 			doc->media[doc->nummedia].height != 0) doc->nummedia++;
 		    else
-			free(doc->media[doc->nummedia].name);
+			g_free(doc->media[doc->nummedia].name);
 		}
 	    }
 	    section_len += line_len;
@@ -736,7 +736,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 			break;
 		    }
 		}
-		free(cp);
+		g_free(cp);
 	    } else if (page_bb_set == NONE &&
 		       iscomment(line+2, "PageBoundingBox:")) {
 		if (sscanf(line+length("%%PageBoundingBox:"), "%d %d %d %d",
@@ -864,7 +864,7 @@ psscan(FILE **fileP, const char *filename, const char *tmpprefix,
 			break;
 		    }
 		}
-		free(cp);
+		g_free(cp);
 	    } else if (page_bb_set == NONE &&
 		       iscomment(line+2, "PageBoundingBox:")) {
 		if (sscanf(line+length("%%PageBoundingBox:"), "%d %d %d %d",
@@ -931,7 +931,7 @@ newpage:
 	    ignore = thispage != 1;
 	}
 	if (!ignore && thispage != nextpage) {
-	    free(label);
+	    g_free(label);
 	    doc->numpages--;
 	    goto continuepage;
 	}
@@ -981,7 +981,7 @@ continuepage:
 			break;
 		    }
 		}
-		free(cp);
+		g_free(cp);
 	    } else if (doc->pages[doc->numpages].media == NULL &&
 		       iscomment(line+2, "PaperSize:")) {
 		cp = get_next_text(line+length("%%PaperSize:"), NULL);
@@ -995,7 +995,7 @@ continuepage:
 			break;
 		    }
 		}
-		free(cp);
+		g_free(cp);
 	    } else if ((page_bb_set == NONE || page_bb_set == ATEND) &&
 		       iscomment(line+2, "PageBoundingBox:")) {
 		sscanf(line+length("%%PageBoundingBox:"), "%s", text);
@@ -1060,7 +1060,7 @@ continuepage:
 	if (!DSCcomment(line)) {
 	    /* Do nothing */
 	} else if (iscomment(line+2, "Page:")) {
-	    free(get_next_text(line+length("%%Page:"), &next_char));
+	    g_free(get_next_text(line+length("%%Page:"), &next_char));
 	    if (sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
 	    if (!ignore && thispage == nextpage) {
 		if (doc->numpages > 0) {
@@ -1143,7 +1143,7 @@ continuepage:
 	if (!preread) section_len += line_len;
 	preread = 0;
 	if (DSCcomment(line) && iscomment(line+2, "Page:")) {
-	    free(get_next_text(line+length("%%Page:"), &next_char));
+	    g_free(get_next_text(line+length("%%Page:"), &next_char));
 	    if (sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
 	    if (!ignore && thispage == nextpage) {
 		if (doc->numpages > 0) {
@@ -1184,16 +1184,16 @@ psfree(doc)
     printf("This document exists\n");
       */
 	for (i=0; i<doc->numpages; i++) {
-	    if (doc->pages[i].label) free(doc->pages[i].label);
+	    if (doc->pages[i].label) g_free(doc->pages[i].label);
 	}
 	for (i=0; i<doc->nummedia; i++) {
-	    if (doc->media[i].name) free(doc->media[i].name);
+	    if (doc->media[i].name) g_free(doc->media[i].name);
 	}
-	if (doc->title) free(doc->title);
-	if (doc->date) free(doc->date);
-	if (doc->pages) free(doc->pages);
-	if (doc->media) free(doc->media);
-	free(doc);
+	if (doc->title) g_free(doc->title);
+	if (doc->date) g_free(doc->date);
+	if (doc->pages) g_free(doc->pages);
+	if (doc->media) g_free(doc->media);
+	g_free(doc);
     }
 }
 
@@ -1214,7 +1214,7 @@ gettextline(line)
 	return get_next_text(line, NULL);
     } else {
 	if (strlen(line) == 0) return NULL;
-	cp = (char *) malloc(strlen(line));
+	cp = (char *) g_malloc(strlen(line));
 	if (cp == NULL) {
 	    fprintf(stderr, "Fatal Error: Dynamic memory exhausted.\n");
 	    exit(-1);
@@ -1306,7 +1306,7 @@ get_next_text(line, next_char)
     *cp = '\0';
     if (next_char) *next_char = line;
     if (!quoted && strlen(text) == 0) return NULL;
-    cp = (char *) malloc(strlen(text)+1);
+    cp = (char *) g_malloc(strlen(text)+1);
     if (cp == NULL) {
 	fprintf(stderr, "Fatal Error: Dynamic memory exhausted.\n");
 	exit(-1);
@@ -1538,7 +1538,7 @@ pscopyuntil(from, to, begin, end, comment)
 	/* iscomment cannot be used here,
 	 * because comment_length is not known at compile time. */
 	if (strncmp(line, comment, comment_length) == 0) {
-	    cp = (char *) malloc(strlen(line)+1);
+	    cp = (char *) g_malloc(strlen(line)+1);
 	    if (cp == NULL) {
 		fprintf(stderr, "Fatal Error: Dynamic memory exhausted.\n");
 		exit(-1);
